#
# spec file for package python-blessed
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-blessed
Version:        1.20.0
Release:        1.4
Summary:        Wrapper around terminal styling, screen positioning, and keyboard input
License:        MIT
URL:            https://github.com/jquast/blessed
Source:         https://files.pythonhosted.org/packages/source/b/blessed/blessed-%{version}.tar.gz
BuildRequires:  %{python_module curses}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.9.0}
BuildRequires:  %{python_module wcwidth >= 0.1.4}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-curses
Requires:       python-six >= 1.9.0
Requires:       python-wcwidth >= 0.1.4
BuildArch:      noarch
%python_subpackages

%description
Blessed is a thin, practical wrapper around terminal capabilities in Python.

Brief Overview
--------------

*Blessed* is a more simplified wrapper around curses, providing :

* Styles, color, and maybe a little positioning without necessarily
  clearing the whole screen first.
* Works great with standard Python string formatting.
* Provides up-to-the-moment terminal height and width, so you can respond to
  terminal size changes.
* Avoids making a mess if the output gets piped to a non-terminal:
  outputs to any file-like object such as *StringIO*, files, or pipes.
* Uses the `terminfo(5)`_ database so it works with any terminal type
  and supports any terminal capability: No more C-like calls to tigetstr_
  and tparm_.
* Keeps a minimum of internal state, so you can feel free to mix and match with
  calls to curses or whatever other terminal libraries you like.
* Provides plenty of context managers to safely express terminal modes,
  automatically restoring the terminal to a safe state on exit.
* Act intelligently when somebody redirects your output to a file, omitting
  all of the terminal sequences such as styling, colors, or positioning.
* Dead-simple keyboard handling: safely decoding unicode input in your
  system's preferred locale and supports application/arrow keys.
* Allows the printable length of strings containing sequences to be
  determined.

Blessed **does not** provide...

* Windows command prompt support.  A PDCurses_ build of python for windows
  provides only partial support at this time -- there are plans to merge with
  the ansi module in concert with colorama to resolve this.

%prep
%autosetup -p1 -n blessed-%{version}
# disable cons25 tests as they fail in OBS
sed -i -e 's:cons25 ::' tests/accessories.py
# do not pull extra deps that are not needed
rm tox.ini

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
export TEST_QUICK=1
%pytest tests

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/blessed
%{python_sitelib}/blessed-%{version}*-info

%changelog
* Thu Dec 14 2023 pgajdos@suse.com
- deleted patches
  - drop-python2-support.patch (upstreamed)
* Thu Dec 14 2023 Petr Gajdos <pgajdos@suse.com>
- update to 1.20.0:
  * introduced `Terminal.get_fgcolor()` and
    `Terminal.get_bgcolor()` to query
  * the terminal for the currently set colors. #237 by
    @stefanholek
  * bugfix: Copy globals dict before iterating to avoid
    `RuntimeError` in multithreaded
  * applications, #248 by @adamnovak
* Mon Jun 26 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Thu Nov  3 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add drop-python2-support.patch to remove python-six dependency
  gh#jquast/blessed#245
- Remove python_module macro definition
- Remove skip_python2 define
- More specific python_sitelib in %%files
* Wed Mar 16 2022 pgajdos@suse.com
- version update to 1.19.1
  1.19
  * introduced truncate() to truncate a string while retaining the
    sequences, #211 by fishermans-friend
  * enhancement: Add small sleep in kbhit() on Windows to reduce CPU
    load #209 by numerlor
  * enhancement: rjust(), ljust(), and center() now accept
    SupportsIndex types, #234
  * enhancement: When 88 colors is detected, it is now interpreted
    as 16 colors rather than raising an AssertionError, #235
  * bugfix: Fix global variable declarations in type annotations, #230
    by mwchase
  1.18
  * bugfix: split_seqs() for some sequences like term.move_left(3), #197.
  * introduced: type annotations, #192 by dlax.
  * bugfix: do not fail when sys.stdin is unset, #195 by Olen
  * docfix: correct “Bottom of the screen” example to use end=''
    and document about it in location.rst, #188 by pyfisch
- python-mock not required
* Wed Aug 26 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.17.10:
  * bugfix: Now imports on 3.10+
  * bugfix: Fix detection of shift+arrow keys when using tmux. :ghissue:`178`.
* Wed May  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.17.5:
  * minor fixes
- Do not pull extra pytest deps and use even latest pytest
* Thu Mar 26 2020 Daniel Wagner <daniel.wagner@suse.com>
- update to 1.17.4
  * optimize length()
  * add pixel_height and pixel_width, for libsixel support
  * Documentation overhaul, plenty of examples and animated
    screenshots.
* Wed Jan 22 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.17.0
  * 24-bit color support
  * move_up(), move_down(), Terminal.move_left(), move_right() which
    are strings that move the cursor one cell in the respective
    direction, are now also callables for moving n cells to the
    given direction, such as term.move_right(9).
  * Context Managers, fullscreen(), hidden_cursor(), and keypad()
    now flush the stream after writing their sequences.
  * deprecated: superscript, subscript, shadow, and dim are no longer
    “compoundable” with colors. Use Unicode text or 256 or 24-bit
    color codes instead.
  * more on https://blessed.readthedocs.io/en/latest/history.html
* Thu Sep  5 2019 Todd R <toddrme2178@gmail.com>
- Set pytest maximum version.
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.15.0:
  * no upstream changelog
- Make sure tests are run
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Jul 17 2018 tchvatal@suse.com
- Tox is not used when building so no need to depend on it
* Wed May  9 2018 toddrme2178@gmail.com
- Add license tag
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
